@@ -6,9 +6,9 @@ __author__ = "Feth Arezki, Julien Miotte, Gaston Tjebbes"
 __copyright__ = "Copyright 2020, Majerti"
 __credits__ = ["Feth Arezki", "Julien Miotte", "Gaston Tjebbes", "Vinay Sajip"]
 __license__ = "GPLv3"
-__version__ = "1RC"
-__maintainer__ = "Feth Arezki"
-__email__ = "feth@majerti.fr"
+__version__ = "1.0.6"
+__maintainer__ = "Tjebbes Gaston"
+__email__ = "gaston@majerti.fr"
 __status__ = "Development"
 
 
@@ -81,7 +81,7 @@ def main():
     parser.add_argument(
         '-V', '--version',
         action='version',
-        version="%%(prog)s (pdf split for autonomie version %s)" % __version__
+        version="%%(prog)s (pdf split for endi version %s)" % __version__
     )
 
     arguments = parser.parse_args()
