@@ -209,7 +209,7 @@ class FrNameRegexDataFinder(RegexDataFinder):
     """
     def __init__(self, **kw):
         kw['regex'] = (
-            r"[ ]+(i?)(M|Mme|Mlle|Madame|Monsieur|Mademoiselle)[ ]+(?P<name>"
+            r"[ ]+(i?)(M.|M|Mme|Mlle|Madame|Monsieur|Mademoiselle)[ ]+(?P<name>"
             r"[-\w ']+)(\n|$)")
         kw['regex_group_name'] = 'name'
         RegexDataFinder.__init__(self, **kw)
